---
name: Bug report
about: Create a report to help us improve
title: ''
labels: bug
assignees: OTBreathe

---

**Describe the bug**
Please describe the bug or error you encountered.  Detail can be added in the sections below.

**Expected behavior**
What should have happened?

**The code that you ran to trigger the bug**
What code did you run to trigger the bug?  If you can't post the whole code, please try to create a minimal code snippet to recreate it.

**The full error output**
Please add the full error output (stack trace).  In particular please include any message that includes `trace_id` or `span_id` as they will help to identify the error.

**Additional context**
Add any other context about the problem here.
